@@ -117,12 +117,6 @@ const startupPhases = {
       read: 1,
       stat: 1,
     },
-    {
-      // bug 1541226, bug 1363586, bug 1541593
-      path: "ProfD:",
-      condition: WIN,
-      stat: 1,
-    },
     {
       path: "ProfLD:.startup-incomplete",
       condition: !WIN, // Visible on Windows with an open marker
@@ -208,6 +202,12 @@ const startupPhases = {
       read: 1,
       close: 1,
     },
+    {
+      // This is the startup lock used to restrict only one IceCat startup at a time.
+      path: `TmpD:icecat-${AppConstants.MOZ_UPDATE_CHANNEL}/parent.lock`,
+      condition: WIN,
+      stat: 1,
+    },
   ],
 
   "before opening first browser window": [
@@ -286,18 +286,6 @@ const startupPhases = {
   // We reach this phase right after showing the first browser window.
   // This means that any I/O at this point delayed first paint.
   "before first paint": [
-    {
-      path: "XREAppFeat:formautofill@mozilla.org.xpi",
-      condition: !WIN,
-      stat: 1,
-      close: 1,
-    },
-    {
-      path: "XREAppFeat:webcompat@mozilla.org.xpi",
-      condition: LINUX,
-      ignoreIfUnused: true, // Sometimes happens in the previous phase
-      close: 1,
-    },
     {
       // We only hit this for new profiles.
       path: "XREAppDist:distribution.ini",
@@ -395,13 +383,6 @@ const startupPhases = {
       condition: LINUX,
       close: 1,
     },
-    {
-      path: "XREAppFeat:webcompat-reporter@mozilla.org.xpi",
-      condition: !WIN,
-      ignoreIfUnused: true,
-      stat: 1,
-      close: 1,
-    },
     {
       // Bug 1660582 - access while running on windows10 hardware.
       path: "ProfD:wmfvpxvideo.guard",
@@ -467,17 +448,6 @@ const startupPhases = {
       condition: WIN,
       stat: 7,
     },
-    {
-      path: "XREAppFeat:screenshots@mozilla.org.xpi",
-      ignoreIfUnused: true,
-      close: 1,
-    },
-    {
-      path: "XREAppFeat:webcompat-reporter@mozilla.org.xpi",
-      ignoreIfUnused: true,
-      stat: 1,
-      close: 1,
-    },
     {
       // bug 1391590
       path: "ProfD:places.sqlite-journal",
@@ -646,26 +616,6 @@ add_task(async function () {
     Cc["@mozilla.org/test/startuprecorder;1"].getService().wrappedJSObject;
   await startupRecorder.done;
 
-  // Add system add-ons to the list of known IO dynamically.
-  // They should go in the omni.ja file (bug 1357205).
-  {
-    let addons = await AddonManager.getAddonsByTypes(["extension"]);
-    for (let addon of addons) {
-      if (addon.isSystem) {
-        startupPhases["before opening first browser window"].push({
-          path: `XREAppFeat:${addon.id}.xpi`,
-          stat: 3,
-          close: 2,
-        });
-        startupPhases["before handling user events"].push({
-          path: `XREAppFeat:${addon.id}.xpi`,
-          condition: WIN,
-          stat: 2,
-        });
-      }
-    }
-  }
-
   // Check for main thread I/O markers in the startup profile.
   let profile = startupRecorder.data.profile.threads[0];
 
