@@ -263,10 +263,16 @@ async function doDismissOneTest({
     "quicksuggest-dismissals-changed"
   );
 
+  let actualResult = await getActualResult({
+    providers: [UrlbarProviderQuickSuggest.name],
+    query: queriesForDismissals[0].query,
+    expectedResult: result,
+  });
+
   triggerCommand({
-    result,
     command,
     feature,
+    result: actualResult,
     expectedCountsByCall: {
       removeResult: 1,
     },
@@ -280,7 +286,7 @@ async function doDismissOneTest({
     "canClearDismissedSuggestions should return true after triggering command"
   );
   Assert.ok(
-    await QuickSuggest.isResultDismissed(result),
+    await QuickSuggest.isResultDismissed(actualResult),
     "The result should be dismissed"
   );
 
@@ -374,10 +380,16 @@ async function doDismissAllTest({ feature, result, command, pref, queries }) {
     "quicksuggest-dismissals-changed"
   );
 
+  let actualResult = await getActualResult({
+    providers: [UrlbarProviderQuickSuggest.name],
+    query: queries[0].query,
+    expectedResult: result,
+  });
+
   triggerCommand({
-    result,
     command,
     feature,
+    result: actualResult,
     expectedCountsByCall: {
       removeResult: 1,
     },
@@ -442,6 +454,44 @@ async function doDismissAllTest({ feature, result, command, pref, queries }) {
   }
 }
 
+/**
+ * Does a search, asserts an actual result exists that matches the given result,
+ * and returns it.
+ *
+ * @param {object} options
+ *   Options object.
+ * @param {SuggestFeature} options.query
+ *   The search string.
+ * @param {UrlbarResult} options.expectedResult
+ *   The expected result.
+ * @param {string[]} [options.providers]
+ *   The providers to query.
+ */
+async function getActualResult({
+  query,
+  expectedResult,
+  providers = [UrlbarProviderQuickSuggest.name],
+}) {
+  info("Doing search to get an actual result: " + JSON.stringify(query));
+  let context = createContext(query, {
+    providers,
+    isPrivate: false,
+  });
+  await check_results({
+    context,
+    matches: [expectedResult],
+  });
+
+  let actualResult = context.results.find(
+    r =>
+      r.providerName == UrlbarProviderQuickSuggest.name &&
+      r.payload.provider == expectedResult.payload.provider
+  );
+  Assert.ok(actualResult, "Search should have returned a matching result");
+
+  return actualResult;
+}
+
 /**
  * Does some "show less frequently" tests where the cap is set in remote
  * settings and Nimbus. See `doOneShowLessFrequentlyTest()`. This function
