@@ -563,6 +563,11 @@ if (!window.FB) {
         }
       },
     },
+    __buffer: {
+      replay: null,
+      calls: [],
+      opts: null,
+    },
   });
 
   window.FB.XFBML.parse();
